@@ -38,6 +38,21 @@ class VariableList2D:
         self.add(other + self.vals[-1])
         return self
 
+    def __add__(self, other):
+        return other + self.value
+
+    def __sub__(self, other):
+        return self.value - other
+
+    def __mul__(self, other):
+        return self.value * other
+
+    def __div__(self, other):
+        return self.value / other
+
+    def __pow__(self, other):
+        return self.value**other
+
     def __getitem__(self, key: int):
         return self.vals[key]
 
@@ -51,6 +66,10 @@ class VariableList2D:
     def from_array(cls, name, arr: np.ndarray):
         return cls(name, arr[0], arr[1])
 
+    @property
+    def value(self):
+        return self.vals[-1]
+
     @property
     def x_values(self):
         return np.array([x[0] for x in self.vals])
